netapp_ontap.resources.security_saml_sp API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.security_saml_sp`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

This API is used to retrieve and display relevant information pertaining to the SAML service provider configuration in the cluster. The POST request creates a SAML service provider configuration if there is none present. The DELETE request removes the SAML service provider configuration. The PATCH request enables and disables SAML in the cluster. Various responses are shown in the examples below.

## Examples

### Retrieving the SAML service provider configuration in the cluster

The following output shows the SAML service provider configuration in the cluster.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SecuritySamlSp

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SecuritySamlSp()
        resource.get()
        print(resource)

Try it out

    SecuritySamlSp(
        {
            "idp_uri": "https://examplelab.customer.com/idp/Metadata",
            "certificate": {
                "serial_number": "156F10C3EB4C51C1",
                "common_name": "cluster1",
                "ca": "cluster1",
            },
            "host": "172.21.74.181",
            "enabled": True,
            "_links": {"self": {"href": "/api/security/authentication/cluster/saml-sp"}},
        }
    )

### Creating the SAML service provider configuration

The following output shows how to create a SAML service provider configuration in the cluster.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SecuritySamlSp

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SecuritySamlSp()
        resource.idp_uri = "https://examplelab.customer.com/idp/Metadata"
        resource.host = "172.21.74.181"
        resource.certificate.ca = "cluster1"
        resource.certificate.serial_number = "156F10C3EB4C51C1"
        resource.post(hydrate=True)
        print(resource)

### Updating the SAML service provider configuration

The following output shows how to enable a SAML service provider configuration in the cluster.
Disabling the configuration requires the client to be authenticated through SAML prior to performing the operation.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SecuritySamlSp

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SecuritySamlSp()
        resource.enabled = True
        resource.patch()

### Deleting the SAML service provider configuration

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SecuritySamlSp

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SecuritySamlSp()
        resource.delete()

## Classes

`class SecuritySamlSp (*args, **kwargs)`

  Allows interaction with SecuritySamlSp objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes a SAML service provider configuration.

    ### Learn more

    - `DOC /security/authentication/cluster/saml-sp`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves a SAML service provider configuration.

    ### Learn more

    - `DOC /security/authentication/cluster/saml-sp`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates a SAML service provider configuration.

    ### Learn more

    - `DOC /security/authentication/cluster/saml-sp`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates a SAML service provider configuration. Note that "common_name" is mutually exclusive with "serial_number" and "ca" in POST. SAML will initially be disabled, requiring a patch to set "enabled" to "true", so that the user has time to complete the setup of the IdP.

    ### Required properties

    - `idp_uri`

    ### Optional properties

    - `certificate`
    - `enabled`
    - `host`

    ### Learn more

    - `DOC /security/authentication/cluster/saml-sp`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class SecuritySamlSpSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SecuritySamlSp object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `certificate GET POST`

    The certificate field of the security_saml_sp.

  `enabled GET PATCH`

    The SAML service provider is enabled. Valid for PATCH and GET operations only.

  `host GET POST`

    The SAML service provider host.

  `idp_uri GET POST`

    The identity provider (IdP) metadata location. Required for POST operations.

    Example: https://idp.example.com/FederationMetadata/2007-06/FederationMetadata.xml

  `links GET`

    The links field of the security_saml_sp.